==> keystone_api-0.3.8.tar.gz: keystone_api-0.3.8/keystone_api/apps/research_products/views.py <==
"""Application logic for rendering HTML templates and handling HTTP requests.

View objects handle the processing of incoming HTTP requests and return the
appropriately rendered HTML template or other HTTP response.
"""

from rest_framework import permissions, viewsets

from .models import *
from .permissions import *
from .serializers import *

__all__ = ['GrantViewSet', 'PublicationViewSet']


class PublicationViewSet(viewsets.ModelViewSet):
    """Manage metadata for research publications."""

    permission_classes = [permissions.IsAuthenticated, permissions.IsAdminUser | GroupMemberAll]
    serializer_class = PublicationSerializer
    filterset_fields = '__all__'

    def get_queryset(self) -> list[Publication]:
        """Return a list of allocation requests for the currently authenticated user"""

        if self.request.user.is_staff:
            return Publication.objects.all()

        return Publication.objects.affiliated_with_user(self.request.user).all()


class GrantViewSet(viewsets.ModelViewSet):
    """Track funding awards and grant information."""

    permission_classes = [permissions.IsAuthenticated, permissions.IsAdminUser | GroupMemberReadGroupAdminWrite]
    serializer_class = GrantSerializer
    filterset_fields = '__all__'

    def get_queryset(self) -> list[Grant]:
        """Return a list of allocation requests for the currently authenticated user"""

        if self.request.user.is_staff:
            return Grant.objects.all()

        return Grant.objects.affiliated_with_user(self.request.user).all()

==> keystone_api-0.3.17.tar.gz: keystone_api-0.3.17/keystone_api/apps/research_products/views.py <==
"""Application logic for rendering HTML templates and handling HTTP requests.

View objects handle the processing of incoming HTTP requests and return the
appropriately rendered HTML template or other HTTP response.
"""

from rest_framework import permissions, viewsets

from .models import *
from .permissions import *
from .serializers import *

__all__ = ['GrantViewSet', 'PublicationViewSet']


class PublicationViewSet(viewsets.ModelViewSet):
    """Manage metadata for research publications."""

    queryset = Publication.objects.all()
    serializer_class = PublicationSerializer
    permission_classes = [
        permissions.IsAuthenticated,
        permissions.IsAdminUser | GroupMemberAll
    ]

    def get_queryset(self) -> list[Publication]:
        """Return a list of allocation requests for the currently authenticated user"""

        if self.request.user.is_staff:
            return self.queryset

        return Publication.objects.affiliated_with_user(self.request.user).all()


class GrantViewSet(viewsets.ModelViewSet):
    """Track funding awards and grant information."""

    queryset = Grant.objects.all()
    serializer_class = GrantSerializer
    permission_classes = [
        permissions.IsAuthenticated,
        permissions.IsAdminUser | GroupMemberReadGroupAdminWrite
    ]

    def get_queryset(self) -> list[Grant]:
        """Return a list of allocation requests for the currently authenticated user"""

        if self.request.user.is_staff:
            return self.queryset

        return Grant.objects.affiliated_with_user(self.request.user).all()
